@@ -12,15 +12,17 @@
 ## @class Chart::Bars
 # Bars class provides all functions which are specific to
 # vertical bars
-package Chart::Bars; # '2.400.2'
+use strict;
+
+package Chart::Bars;
+
+our $VERSION = 2.400.3;
+@Chart::Bars::ISA     = qw(Chart::Base);
+
 use Chart::Base;
 use GD;
 use Carp;
 
-use strict;
-
-@Chart::Bars::ISA     = qw(Chart::Base);
-
 #>>>>>>>>>>>>>>>>>>>>>>>>>>#
 #  public methods go here  #
 #<<<<<<<<<<<<<<<<<<<<<<<<<<#
