@@ -21,7 +21,8 @@
 # \see FilledDiamond\n
 # \see OpenRectangle\n
 # \see FilledRectangle\n
-package Chart::BrushStyles; # '2.400.2'
+package Chart::BrushStyles;
+our $VERSION = 2.400.3;
 
 use Chart::Base;
 use GD;
