@@ -18,7 +18,8 @@
 # This class provides all functions which are specific to
 # composite charts
 
-package Chart::Composite; # '2.400.2'
+package Chart::Composite;
+our $VERSION = 2.400.3;
 
 use Chart::Base;
 use GD;
