@@ -15,7 +15,8 @@
 # @brief Direction class derived class for Chart to implement direction
 # charts
 
-package Chart::Direction; # '2.400.2'
+package Chart::Direction;
+our $VERSION = 2.400.3;
 
 use Chart::Base;
 use GD;
