@@ -10,8 +10,8 @@
 # @version 2.4.10
 #
 
-package Chart::ErrorBars; # '2.400.2'
-
+package Chart::ErrorBars;
+our $VERSION = 2.400.3;
 use Chart::Base;
 use GD;
 use Carp;
