@@ -12,7 +12,8 @@
 # This class provides all functions which are specific to
 # horizontal bars
 #
-package Chart::HorizontalBars; # '2.400.2'
+package Chart::HorizontalBars;
+our $VERSION = 2.400.3;
 
 use Chart::Base;
 use GD;
