@@ -17,7 +17,8 @@
 # lines
 #
 
-package Chart::LinesPoints; # '2.400.2'
+package Chart::LinesPoints;
+our $VERSION = 2.400.3;
 
 use Chart::Base;
 use GD;
