@@ -44,7 +44,8 @@
 #   of its area, not just a line color.  So the legend shou a square
 #   of the color and pattern for each dataset.
 
-package Chart::Mountain; # '2.400.2'
+package Chart::Mountain;
+our $VERSION = 2.400.3;
 
 use Chart::Base;
 use GD;
