@@ -10,7 +10,8 @@
 ## @class Chart::Pareto
 # @brief Pareto class derived class for Chart to implement
 #
-package Chart::Pareto; # '2.400.2'
+package Chart::Pareto;
+our $VERSION = 2.400.3;
 
 use Chart::Base;
 use GD;
