@@ -10,7 +10,8 @@
 ## @class Chart::Pie
 # @brief Pie class derived class for Chart to implement pies
 #
-package Chart::Pie; # '2.400.2'
+package Chart::Pie;
+our $VERSION = 2.400.3;
 
 use Chart::Base;
 use GD;
