@@ -16,7 +16,8 @@
 # This class provides all functions which are specific to
 # points
 #
-package Chart::Points; # '2.400.2'
+package Chart::Points;
+our $VERSION = 2.400.3;
 
 use Chart::Base;
 use GD;
