@@ -13,7 +13,8 @@
 # This class provides all functions which are specific to
 # splitted plots
 #
-package Chart::Split; # 2.400.2
+package Chart::Split;
+our $VERSION = 2.400.3;
 
 use Chart::Base;
 use GD;
@@ -21,7 +22,6 @@ use Carp;
 use strict;
 
 @Chart::Split::ISA     = qw(Chart::Base);
-$Chart::Split::VERSION = '2.4.10';
 
 #>>>>>>>>>>>>>>>>>>>>>>>>>>#
 #  public methods go here  #
