@@ -15,7 +15,8 @@
 #
 # This class provides all functions which are specific to
 # stacked bars
-package Chart::StackedBars; # '2.400.2'
+package Chart::StackedBars;
+our $VERSION = 2.400.3;
 
 use Chart::Base;
 use GD;
